@@ -47,11 +47,17 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#if !defined(S_IREAD) && defined(S_IRUSR)
+#define S_IREAD  S_IRUSR
+#endif
+#if !defined(S_IWRITE) && defined(S_IWUSR)
+#define S_IWRITE S_IWUSR
+#endif
 
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(WIN32)
+#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(_WIN32)
 #include <pwd.h>
 #include <signal.h>
 #ifdef HAVE_SYS_WAIT_H
@@ -92,6 +98,9 @@ static const CHAR *modulepatterns[] = {
 	"*.[Ss][Tt][Mm]",
 	"*.[Ss][Tt][Xx]",
 	"*.[Uu][Ll][Tt]",
+#if LIBMIKMOD_VERSION >= 0x030303
+	"*.[Uu][Mm][Xx]",			/* unreal umx container */
+#endif
 	"*.[Uu][Nn][Ii]",
 	"*.[Xx][Mm]",
 	NULL
@@ -105,7 +114,7 @@ static const CHAR *prefixmodulepatterns[] = {
 	NULL
 };
 
-#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(WIN32)
+#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(_WIN32)&&!defined(_mikmod_amiga)
 /* Drop all root privileges we might have. */
 BOOL DropPrivileges(void)
 {
@@ -251,7 +260,7 @@ static BOOL filename2short (const char *l, char *s, int len_s)
 	}
 }
 
-#elif defined(WIN32)
+#elif defined(_WIN32)
 
 static BOOL filename2short (const char *l, char *s, int len_s)
 {
@@ -420,10 +429,15 @@ static int MA_truncate (int fd, const char *startpat, int start, int end, char *
 	return dest;
 }
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#ifdef _mikmod_amiga
+#define start_redirect() do {} while (0)
+#define stop_redirect() do {} while (0)
+#endif
+
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 
 static int rd_err, rd_outbak=-1, rd_errbak;
-#ifdef WIN32
+#ifdef _WIN32
 static char *rd_file = NULL;
 #endif
 
@@ -433,7 +447,7 @@ static void start_redirect (void)
 	fflush(stdout);
 	fflush(stderr);
 
-#ifdef WIN32
+#ifdef _WIN32
 	/* "nul" seems not to work, use a temp file instead */
 	rd_err = get_tmp_file(NULL, &rd_file);
 #else
@@ -460,7 +474,7 @@ static void stop_redirect (void)
 		close(rd_errbak);
 		rd_outbak = -1;
 
-#ifdef WIN32
+#ifdef _WIN32
 		if (rd_file) {
 			unlink (path_conv_sys(rd_file));
 			free (rd_file);
@@ -493,7 +507,7 @@ int MA_dearchive(const CHAR *arc, const CHAR *file, CHAR **extracted)
 		if (MA_identify(arc, config.archiver[t].location, config.archiver[t].marker)) {
 			/* display "extracting" message, as this may take some time... */
 			display_extractbanner();
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 			/* extracting, the non-Unix way */
 
 			tmp_file = get_tmp_name();
@@ -576,7 +590,7 @@ int MA_dearchive(const CHAR *arc, const CHAR *file, CHAR **extracted)
 
 	if (tmp_fd >= 0) {
 		lseek (tmp_fd, 0, SEEK_SET);
-		if (config.archiver[t].skippat ||
+		if ((config.archiver[t].skippat && config.archiver[t].skippat[0]) ||
 			config.archiver[t].skipstart>0 || config.archiver[t].skipend>0) {
 			char *f;
 
@@ -639,7 +653,7 @@ BOOL MA_TestName (const char *filename, BOOL plist, BOOL deep)
 /* Examines file 'filename' to add modules to the playlist 'pl' */
 void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 {
-	int t, archive = 0;
+	int t, archive = -1;
 	struct stat statbuf;
 
 	if (stat(path_conv_sys(filename), &statbuf))
@@ -664,11 +678,11 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 	for (t = 0; t<config.cnt_archiver; t++)
 		if (MA_identify (filename, config.archiver[t].location,
 						 config.archiver[t].marker)) {
-			archive = t + 1;
+			archive = t;
 			break;
 		}
 
-	if (archive--) {
+	if (archive >= 0) {
 		if (config.archiver[archive].list && *config.archiver[archive].list) {
 			/* multi-file archive, need to invoke list function */
 			BOOL endspace = config.archiver[archive].nameoffset < 0;
@@ -676,14 +690,21 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 			char *string = (char *) malloc (PATH_MAX + 2 + offset);
 			char *command;
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 /* Archive display, the non-Unix way */
 			FILE *file;
+			char *dest = NULL;
 
+#ifdef _mikmod_amiga
+			dest = get_tmp_name();
+#endif
 			command = get_command (config.archiver[archive].list,
-								   path_conv_sys(filename), NULL, NULL);
+								   path_conv_sys(filename), NULL, dest);
 			start_redirect();
-#if defined(__WATCOMC__)||(defined(WIN32)&&!defined(LCC))
+#ifdef _mikmod_amiga
+			system(command);
+			file = fopen(dest, "r");
+#elif defined(__WATCOMC__)||(defined(_WIN32)&&!defined(__LCC__))
 			file = _popen (command, "r");
 #else
 			file = popen (command, "r");
@@ -705,7 +726,11 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 					PL_Add(pl, string + t, filename, 0, 0);
 				fgets(string, PATH_MAX + offset + 1, file);
 			}
-#if defined(__WATCOMC__)||defined(WIN32)
+#ifdef _mikmod_amiga
+			fclose(file);
+			unlink(dest);
+			free(dest);
+#elif defined(__WATCOMC__)||defined(_WIN32)
 			_pclose(file);
 #else
 			pclose(file);
@@ -797,8 +822,7 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 			CHAR *spare;
 
 			dot = strrchr(filename, '.');
-			slash = strrchr(filename, PATH_SEP);
-
+			slash = FIND_LAST_DIRSEP(filename);
 			if (!slash)
 				slash = filename;
 			else
