@@ -282,7 +282,26 @@ static char tarbzip2ext[] = ".TAR.BZ2 .TBZ .TBZ2";
 
 static ARCHIVE archiver_def[] = {
 	/* location, marker, list, filenames column, extract, skippat, skipstart, skipend */
-#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(WIN32)
+#ifdef _mikmod_amiga
+	{  0,  pksignat, "unzip -vqq \"%a\" > \"%d\"",
+				 58, "unzip -pqq \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{ 20, zoosignat, "zoo lq \"%a\" > \"%d\"",
+				 47, "zoo xpq \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{  0, rarsignat, "unrar v -c- \"%a\" > \"%d\"",
+				  1, "unrar p -inul \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{  2,  lhsignat, "lha vvq \"%a\" > \"%d\"",
+				 -1, "lha pq \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{  2,  lzsignat, "lha vvq \"%a\" > \"%d\"",
+				 -1, "lha pq \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{257, tarsignat, "tar -tf \"%a\" > \"%d\"",
+				  0, "tar -xOf \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{ -1,  targzext, "tar -tzf \"%a\" > \"%d\"",
+				  0, "tar -xOzf \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{ -1, tarbzip2ext, "tar --use-compress-program=bzip2 -tf \"%a\" > \"%d\"",
+				    0, "tar --use-compress-program=bzip2 -xOf \"%a\" \"%f\" > \"%d\"", NULL, 0, 0},
+	{  0,    gzsignat, NULL, 0, "gzip -dqc \"%a\" > \"%d\"", NULL, 0, 0},
+	{  0, bzip2signat, NULL, 0, "bzip2 -dqc \"%a\" > \"%d\"", NULL, 0, 0}
+#elif !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(_WIN32)
 	{  0,  pksignat, "unzip -vqq \"%a\"",
 				 58, "unzip -pqq \"%a\" \"%f\"", NULL, 0, 0},
 	{ 20, zoosignat, "zoo lq \"%a\"",
@@ -332,7 +351,7 @@ static ARCHIVE archiver_def[] = {
 
 char *CF_GetFilename(void)
 {
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 	return get_cfg_name("mikmod.cfg");
 #else
 	return get_cfg_name(".mikmodrc");
@@ -341,7 +360,7 @@ char *CF_GetFilename(void)
 
 char *CF_GetDefaultFilename(void)
 {
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 	return NULL;
 #else
 	return str_sprintf2("%s" PATH_SEP_STR "%s", PACKAGE_DATA_DIR, "mikmodrc");
@@ -704,8 +723,8 @@ BOOL CF_Save(CONFIG * cfg)
 #endif
 	rc_write_bool("WINDOWTITLE", cfg->window_title,
 	              "WINDOWTITLE = Yes|No, set the term/window title to song name\n"
-				  "    (or filename it no title), default: Yes\n");
-	
+				  "    (or filename if song has no title), default: Yes\n");
+
 	rc_write_string ("THEME",cfg->themes[cfg->theme].name,
 					 "THEME = \"name\", name of the theme to use, default: <defaultColor>");
 	if (cfg->cnt_themes>THEME_COUNT) {
