@@ -39,7 +39,7 @@
 #  include "mgetopt.h"
 #endif
 #include <ctype.h>
-#ifndef WIN32
+#ifndef _WIN32
 #  include <signal.h>
 #endif
 #include <stdarg.h>
@@ -259,7 +259,7 @@ static void exit_player(int exitcode, const char *message, ...)
 	exit(exitcode);
 }
 
-#ifndef WIN32
+#ifndef _WIN32
 /* signal handlers */
 static RETSIGTYPE GotoNext(int signum)
 {
@@ -598,7 +598,7 @@ static BOOL player_handle_key(MWINDOW *win, int ch)
 			status.quit = 1;
 			break;
 		case CTRL_L:
-#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(WIN32)
+#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(_WIN32)
 		case KEY_CLEAR:
 #endif
 			win_panel_repaint_force();
@@ -845,8 +845,8 @@ int main(int argc, char *argv[])
 #endif
 
 	/* Find program name without path component */
-	PRG_NAME = (strrchr(argv[0], PATH_SEP)) ?
-		strrchr(argv[0], PATH_SEP) + 1 : argv[0];
+	pos = FIND_LAST_DIRSEP(argv[0]);
+	PRG_NAME = (pos)? pos + 1 : argv[0];
 
 	for (t = 0; t < argc; t++)
 		if ((!strcmp(argv[t], "-norc")) || (!strcmp(argv[t], "--norc"))) {
@@ -870,7 +870,7 @@ int main(int argc, char *argv[])
 	opterr = 0;
 	while ((t = getopt_long_only(argc, argv,
 								 "d:o:f:r:v:y:p:iFlaxctsSqn::N:Vh",
-								 options, NULL)) != ERR) {
+								 options, NULL)) != -1) {
 		switch (t) {
 		  case 'd':				/* -d --driver */
 #if LIBMIKMOD_VERSION >= 0x030107
@@ -1063,7 +1063,7 @@ int main(int argc, char *argv[])
 	Player_SetConfig(&config);
 	use_threads = MP_Init();
 
-#ifndef WIN32
+#ifndef _WIN32
 	signal(SIGTERM, ExitGracefully);
 	signal(SIGINT, ExitGracefully);
 #if defined(__linux)
