@@ -43,12 +43,12 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(WIN32)
+#if !defined(__OS2__)&&!defined(__EMX__)&&!defined(__DJGPP__)&&!defined(_WIN32)
 #include <pwd.h>
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
-#if defined(WIN32)
+#if defined(_WIN32)
 #include <time.h>
 #else
 #include <sys/time.h>
@@ -59,7 +59,93 @@
 #include "marchive.h"
 #include "mutilities.h"
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#ifdef _mikmod_amiga
+#include <proto/exec.h>
+#include <proto/dos.h>
+#endif
+
+#if defined(__DJGPP__)
+static const char *get_homedir (void)
+{
+	return "C:"; /* good enough for msdos */
+}
+#elif defined(_mikmod_amiga)
+static const char *get_homedir (void)
+{
+	static char homdir[PATH_MAX];
+	static char *home = NULL;
+	if (!home) {
+		BPTR lock = GetProgramDir();
+		if (!lock || !NameFromLock(lock, homdir, PATH_MAX))
+			strcpy(homdir, "SYS:");
+		if (!homdir[0]) /* possible?? */
+			strcpy(homdir, "SYS:");
+		else {
+			home = homdir + strlen(homdir);
+			if (!IS_PATH_SEP(home[-1])) {
+				home[0] = PATH_SEP;
+				home[1] = 0;
+			}
+		}
+		home = homdir;
+	}
+	return home;
+}
+#elif defined(__OS2__)||defined(__EMX__)
+static const char *get_homedir (void)
+{
+	const char *home = getenv("HOME");
+	if (!home || !*home) return "C:";
+	return home;
+}
+#elif defined(_WIN32)
+static const char *get_homedir (void)
+{
+	const char *home;
+# ifndef _WIN64
+	static int is_w9x = -1;
+	if (is_w9x < 0) {
+		OSVERSIONINFO v;
+		v.dwOSVersionInfoSize = sizeof(v);
+		if (!GetVersionEx(&v) || v.dwMajorVersion < 4 ||
+			v.dwPlatformId < VER_PLATFORM_WIN32_NT) {
+			is_w9x = 1;
+		}
+		else	is_w9x = 0;
+	}
+	if (is_w9x) return "C:";
+# endif
+	home = getenv("USERPROFILE");
+	if (!home || !*home) return "C:";
+	return home;
+}
+#else /* unix */
+static const char *get_homedir (void)
+{
+	static const char *home = NULL;
+	static char d[PATH_MAX];
+	if (!home) {
+		struct passwd *pw = getpwuid(getuid());
+		memset(d, 0, sizeof(d));
+		if (pw && pw->pw_dir) {
+			strncpy(d, pw->pw_dir, sizeof(d));
+			d[sizeof(d) - 1] = 0;
+			home = d;
+		}
+		else if ((home = getenv("HOME")) != NULL) {
+			strncpy(d, home, sizeof(d));
+			d[sizeof(d) - 1] = 0;
+			home = d;
+		}
+		else {
+			home = ""; /* fubar'ed.. */
+		}
+	}
+	return home;
+}
+#endif /* get_homedir */
+
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 
 void path_conv(char *file)
 {
@@ -137,9 +223,11 @@ BOOL path_relative(const char *path)
 	if (!path)
 		return 1;
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 	if (*path && (path[1] == ':'))
 		return 0;
+#elif defined(_mikmod_amiga)
+	if (strchr(path, ':')) return 0;
 #endif
 
 	return (*path != PATH_SEP);
@@ -168,7 +256,7 @@ static int m_mkstemp (char *tmpl)
 	XXXXXX = &tmpl[len - 6];
 
 	/* Get some more or less random data.  */
-#ifdef WIN32
+#ifdef _WIN32
 	value = Time1000();
 	value = ((value % 1000) ^ (value / 1000)) + counter++;
 #else
@@ -203,7 +291,7 @@ static int m_mkstemp (char *tmpl)
 			/* Any other error will apply also to other names we might
 			   try, and there are 2^32 or so of them, so give up now. */
 			return -1;
-    }
+	}
 
 	/* We got out of the loop because we ran out of combinations to try.  */
 	return -1;
@@ -221,23 +309,24 @@ int get_tmp_file (const char *tmpl, char **name_used)
 	int retval;
 
 	if (!tmpdir) {
+#if defined(_mikmod_amiga)
+		tmpdir = "T:";
+#else /* ! amiga: */
 		tmpdir = getenv ("TMPDIR");
 		if (!tmpdir) tmpdir = getenv ("TMP");
 		if (!tmpdir) tmpdir = getenv ("TEMP");
 #ifdef P_tmpdir
 		if (!tmpdir) tmpdir = P_tmpdir;
 #endif
-		if (!tmpdir) {
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
-			tmpdir = "C:\\";
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
+		if (!tmpdir) tmpdir = "C:\\";
 #else
-			tmpdir = "/tmp";
+		if (!tmpdir) tmpdir = "/tmp";
 #endif
-		}
-		if (tmpdir [strlen (tmpdir) - 1] == PATH_SEP_SYS)
+		if (*tmpdir && tmpdir[strlen(tmpdir) - 1] == PATH_SEP_SYS)
 			tmpsep = "";
-		else
-			tmpsep = PATH_SEP_SYS_STR;
+		else	tmpsep = PATH_SEP_SYS_STR;
+#endif /* !amiga */
 	}
 	if (tmpl == NULL) tmpl = "mmXXXXXX";
 
@@ -259,7 +348,7 @@ int get_tmp_file (const char *tmpl, char **name_used)
 	return retval;
 }
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 /* allocate and return a name for a temporary file
    (under UNIX not used because of tempnam race condition) */
 char *get_tmp_name(void)
@@ -268,13 +357,17 @@ char *get_tmp_name(void)
 #if defined(__OS2__) && defined(__WATCOMC__)
 	tmp_file = str_sprintf2("%s" PATH_SEP_STR "%s", getenv("TEMP"),
 							"!MikMod.tmp");
-#elif defined(WIN32)
+#elif defined(_WIN32)
 	if (!(tmp_file = _tempnam(NULL, ".mod")))
-		if (!(tmp_file = _tempnam(getenv("HOME"), ".mod")))
+		if (!(tmp_file = _tempnam(get_homedir(), ".mod")))
 			return NULL;
+#elif defined(_mikmod_amiga)
+	char s[16];
+	sprintf(s,"%d", rand());
+	tmp_file = str_sprintf("T:%s.mik", s);
 #else
 	if (!(tmp_file = tempnam(NULL, ".mod")))
-		if (!(tmp_file = tempnam(getenv("HOME"), ".mod")))
+		if (!(tmp_file = tempnam(get_homedir(), ".mod")))
 			return NULL;
 #endif
 	path_conv(tmp_file);
@@ -286,21 +379,11 @@ char *get_tmp_name(void)
    'name': filename without the path */
 char *get_cfg_name(const char *name)
 {
-	const char *home = getenv("HOME");
-	char *p;
-	if (!home) {
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
-		home = "C:";
+#if defined(_mikmod_amiga)
+	char *p = str_sprintf2("%s%s", get_homedir(), name);
 #else
-		struct passwd *pw = getpwuid(getuid());
-
-		if (pw)
-			home = pw->pw_dir;
-		else
-			return NULL;
+	char *p = str_sprintf2("%s" PATH_SEP_STR "%s", get_homedir(), name);
 #endif
-	}
-	p = str_sprintf2("%s" PATH_SEP_STR "%s", home, name);
 	path_conv (p);
 	return p;
 }
@@ -323,7 +406,7 @@ int mik_snprintf(char *buffer, size_t n, const char *format, ...)
 
 unsigned long Time1000(void)
 {
-#ifdef WIN32
+#ifdef _WIN32
 	static __int64 Freq = 0;
 	static __int64 LastCount = 0;
 	static __int64 LastRest = 0;
@@ -365,8 +448,7 @@ unsigned long Time1000(void)
 #endif
 }
 
-#if defined(__OS2__)||defined(__EMX__)||(defined(WIN32)&&!defined(__MINGW32__))
-/* FIXME , untested under OS2 */
+#if defined(_WIN32)&&!defined(__MINGW32__)&&!defined(__WATCOMC__)
 DIR* opendir (const char* dirName)
 {
 	struct stat statbuf;
@@ -382,19 +464,13 @@ DIR* opendir (const char* dirName)
 		dir->name[strlen(dir->name)-1] != PATH_SEP)
 		strcat (dir->name,PATH_SEP_SYS_STR);
 
-#ifdef WIN32
 	strcat (dir->name, "*");
 	dir->handle = INVALID_HANDLE_VALUE;
-#elif defined(__OS2__)||defined(__EMX__)
-	strcat (dir->name, "*.*");
-	dir->handle = (unsigned long*) HDIR_CREATE;
-#endif
 	dir->filecnt = 0;
 
 	return dir;
 }
 
-#ifdef WIN32
 struct dirent *readdir (DIR* dir)
 {
 	WIN32_FIND_DATA fileBuffer;
@@ -421,44 +497,7 @@ int closedir (DIR* dir)
 	free (dir);
 	return 0;
 }
-
-#elif defined(__OS2__)||defined(__EMX__)
-
-struct dirent *readdir (DIR* dir)
-{
-	FILEFINDBUF3 fileBuffer = {0};
-	ULONG fileCnt = 1;
-
-	if (dir->filecnt == 0) {
-		if (DosFindFirst(dir->name, (PHDIR) &dir->handle,
-						 FILE_SYSTEM | FILE_HIDDEN | FILE_DIRECTORY,
-						 (PVOID) &fileBuffer,
-						 sizeof(FILEFINDBUF3),
-						 &fileCnt,
-						 FIL_STANDARD))
-			return NULL;
-	} else if (DosFindNext((HDIR) dir->handle,
-						   (PVOID) &fileBuffer,
-						   sizeof(FILEFINDBUF3),
-						   &fileCnt))
-		return NULL;
-
-	strcpy (dir->d_name, fileBuffer.achName);
-	dir->filecnt++;
-
-	return dir;
-}
-
-int closedir (DIR* dir)
-{
-	if (dir->handle != (unsigned long*) HDIR_CREATE)
-		DosFindClose ((HDIR) dir->handle);
-	free (dir);
-	return 0;
-}
-#endif
-
-#endif
+#endif /* dirent _WIN32 */
 
 #if LIBMIKMOD_VERSION < 0x030200
 static char *skip_number(char *str)
