@@ -1229,7 +1229,7 @@ WIDGET *wid_colorsel_add(DIALOG *d, int spacing, const char *hotkeys, int active
 		for (i=0; i<strlen(w->hkeys); i++)
 			w->hkeys[i] = toupper(w->hkeys[i]);
 	} else
-		memcpy (&w->hkeys, &"\0\0\0\0\0", 5);
+		memset (&w->hkeys, 0, 5);
 	w->sel_mode = WID_SEL_SINGLE;
 	dialog_add(d, (WIDGET *) w);
 	return (WIDGET *) w;
@@ -1290,7 +1290,7 @@ static BOOL dialog_handle_key(MWINDOW *win, int ch)
 	int ret, i;
 
 	/* Handle keys common for all widgets here */
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 	if (ch == KEY_ESC) {
 		dialog_close(d);
 		return 1;
